@@ -32,7 +32,7 @@ pgfwrtext (primitive * np, nametype * tp, double x, double y) {
     wstring (&output, np->name);
     putchar (')');
   }
-  if (tp->next_ != NULL) {
+  if (tp->nextname != NULL) {
     putchar ('{');
     texstacktext (np, tp);
   } else {
@@ -154,14 +154,11 @@ pgfstartdraw (int initial, primitive * node, int lsp) {
   Char sep;
   double fill = -1.0;
 
-  if (lsp == XLinvis) {
-    printf ("\\fill");
-  } else if (initial == 0) {
-    printf ("\\dpicdraw");
-  } else {
-    printf ("\\filldraw");
+  if (lsp == XLinvis) { printf ("\\fill"); }
+  else if (initial == 0) { printf ("\\dpicdraw"); }
+  else { printf ("\\filldraw");
     /* initial = 1 or 3 for filled arrowheads */
-  }
+    }
   switch (node->ptype) {
 
   case XBLOCK:
@@ -169,15 +166,15 @@ pgfstartdraw (int initial, primitive * node, int lsp) {
     break;
 
   case XLbox:
-    fill = node->Upr.Ubox.boxfill;
+    fill = node->boxfill_;
     break;
 
   case XLcircle:
-    fill = node->Upr.Ucircle.cfill;
+    fill = node->circlefill_;
     break;
 
   case XLellipse:
-    fill = node->Upr.Uellipse.efill;
+    fill = node->ellipsefill_;
     break;
 
   case XLarc:
@@ -185,92 +182,71 @@ pgfstartdraw (int initial, primitive * node, int lsp) {
   case XLarrow:
   case XLmove:
   case XLspline:
-    fill = node->Upr.Uline.lfill;
+    fill = node->linefill_;
     break;
   }
   fill = ((long) floor ((fill * 1000000L) + 0.5)) / 1000000.0;
   if ((node->shadedp != NULL) || (sshade != NULL)) {
     printf ("[fill=");
-    if (node->shadedp != NULL) {
-      wstring (&output, node->shadedp);
-    } else {
-      wstring (&output, sshade);
-    }
-    sep = ',';
-  } else if ((fill >= 0.0) && (fill <= 1.0)) {
+    if (node->shadedp != NULL) { wstring (&output, node->shadedp); }
+    else { wstring (&output, sshade); }
+    sep = ','; }
+  else if ((fill >= 0.0) && (fill <= 1.0)) {
     printf ("[fill=");
-    if (fill == 0.0) {
-      printf ("black");
-    } else if (fill == 0.25) {
-      printf ("darkgray");
-    } else if (fill == 0.5) {
-      printf ("gray");
-    } else if (fill == 0.75) {
-      printf ("lightgray");
-    } else if (fill == 1.0) {
-      printf ("white");
-    } else {
+    if (fill == 0.0) { printf ("black"); }
+    else if (fill == 0.25) { printf ("darkgray"); }
+    else if (fill == 0.5) { printf ("gray"); }
+    else if (fill == 0.75) { printf ("lightgray"); }
+    else if (fill == 1.0) { printf ("white"); }
+    else {
       printf ("white!");
       wfloat (&output, fill * 100);
       printf ("!black");
-    }
-    sep = ',';
-  } else {
-    sep = '[';
-  }
+      }
+    sep = ','; }
+  else { sep = '['; }
   if ((initial == 1) || (initial == 3)) {
     printf ("%cline width=0bp", sep);
-    sep = ',';
-  } else if ((node->lthick >= 0.0) && (node->lthick != gslinethick)) {
+    sep = ','; }
+  else if ((node->lthick >= 0.0) && (node->lthick != gslinethick)) {
     printf ("%cline width=", sep);
     wfloat (&output, node->lthick);
     printf ("bp");
     sep = ',';
-  }
+    }
   if (((node->outlinep != NULL) || (soutline != NULL)) && (lsp != XLinvis)) {
     printf ("%cdraw=", sep);
-    if (node->outlinep != NULL) {
-      wstring (&output, node->outlinep);
-    } else {
-      wstring (&output, soutline);
-    }
+    if (node->outlinep != NULL) { wstring (&output, node->outlinep); }
+    else { wstring (&output, soutline); }
     if ((initial == 1) || (initial == 3)) {
       printf (",fill=");
-      if (node->outlinep != NULL) {
-	wstring (&output, node->outlinep);
-      } else {
-	wstring (&output, soutline);
+      if (node->outlinep != NULL) { wstring (&output, node->outlinep); }
+      else { wstring (&output, soutline); }
       }
-    }
     sep = ',';
-  }
+    }
   if ((lsp == XLdashed) && (initial != 1) && (initial != 3)) {
-    if (node->lparam <= 0) {
-      printf ("%cdashed", sep);
-    } else {
+    if (node->lparam <= 0) { printf ("%cdashed", sep); }
+    else {
       printf ("%cdash pattern=on ", sep);
       wfloat (&output, node->lparam / fsc);
       printf ("in off ");
       wfloat (&output, node->lparam / fsc);
       printf ("in");
-    }
-    sep = ',';
-  } else if (lsp == XLdotted) {
-    if (node->lparam <= 0) {
-      printf ("%cdotted", sep);
-    } else {
+      }
+    sep = ','; }
+  else if (lsp == XLdotted) {
+    if (node->lparam <= 0) { printf ("%cdotted", sep); }
+    else {
       printf ("%ccap=round,dash pattern=on ", sep);
       printf ("0pt off ");
       wfloat (&output, node->lparam * 72 / fsc);
       printf ("bp");
-    }
+      }
     sep = ',';
-  }
-  if (sep == ',') {
-    putchar (']');
-  } else {
-    putchar (' ');
-  }
+    }
+  if (sep == ',') { putchar (']'); }
+  else { putchar (' '); }
 }
 
 void
@@ -290,7 +266,7 @@ pgfarcahead (postype C, postype point, int atyp, nametype * sou, double ht,
     wstring (&output, soutline);
     printf (",fill=");
     wstring (&output, soutline);
-  }
+    }
   putchar (']');
   /* Trace arrowhead outline */
   if ((atyp == 0) && (lwi < ((wid - lwi) / 2))) {
@@ -302,14 +278,14 @@ pgfarcahead (postype C, postype point, int atyp, nametype * sou, double ht,
     popgwarc (Co, radius, posangle (point, Co), posangle (Ao, Co), ccw);
     ddash ();
     wprop (Ao, Co, radius - lwi, lwi, radius);
-    popgwarc (Co, radius - lwi, posangle (Ao, Co), posangle (*P, Co), -ccw);
-  } else if ((atyp == 3) && (lwi < ((wid - lwi) / 2))) {
+    popgwarc (Co, radius - lwi, posangle (Ao, Co), posangle (*P, Co), -ccw); }
+  else if ((atyp == 3) && (lwi < ((wid - lwi) / 2))) {
     wpos (Px);
     popgwarc (Cix, radius, posangle (Px, Cix), posangle (Ai, Cix), ccw);
     popgwarc (Ci, radius, posangle (Ai, Ci), posangle (point, Ci), -ccw);
     popgwarc (Co, radius, posangle (point, Co), posangle (Ao, Co), ccw);
-    popgwarc (Cox, radius, posangle (Ao, Cox), posangle (Px, Cox), -ccw);
-  } else {
+    popgwarc (Cox, radius, posangle (Ao, Cox), posangle (Px, Cox), -ccw); }
+  else {
     Q.xpos = (Ao.xpos + Ai.xpos) / 2;
     Q.ypos = (Ao.ypos + Ai.ypos) / 2;
     wpos (Q);
@@ -319,7 +295,7 @@ pgfarcahead (postype C, postype point, int atyp, nametype * sou, double ht,
     popgwarc (Co, radius, posangle (point, Co), posangle (Ao, Co), ccw);
     ddash ();
     wpos (Q);
-  }
+    }
   pgfendpath ();
 }
 
@@ -332,7 +308,6 @@ pgfdraw (primitive * node) {
   boolean v;
   nametype *sf, *sg;
   int TEMP;
-  primitive *With1;
 
   getlinespec (node, &lsp, &tn);
   lth = qenv (node, XLlinethick, node->lthick);
@@ -340,113 +315,104 @@ pgfdraw (primitive * node) {
 
   case XLbox:
   case XBLOCK:
-    if (node->ptype == XBLOCK) {
-      v = drawn (node, lsp, -1.0);
-    } else {
-      v = drawn (node, lsp, node->Upr.Ubox.boxfill);
-    }
+    if (node->ptype == XBLOCK) { v = drawn (node, lsp, -1.0); }
+    else { v = drawn (node, lsp, node->boxfill_); }
     if (v) {
       pgfstartdraw (0, node, lsp);
-      pgfbox (node->aat, node->Upr.Ubox.boxwidth / 2,
-	      node->Upr.Ubox.boxheight / 2, node->Upr.Ubox.boxradius);
-    }
+      pgfbox (node->aat, node->boxwidth_ / 2,
+	      node->boxheight_ / 2, node->boxradius_);
+      }
     pgfwrtext (node, node->textp, node->aat.xpos, node->aat.ypos);
     break;
 
   case XLellipse:
-    if (drawn (node, lsp, node->Upr.Uellipse.efill)) {
+    if (drawn (node, lsp, node->ellipsefill_)) {
       pgfstartdraw (0, node, lsp);
       wpos (node->aat);
       printf (" ellipse (");
-      wfloat (&output, node->Upr.Uellipse.elwidth / 2 / fsc / 2.54);
+      wfloat (&output, node->ellipsewidth_ / 2 / fsc / 2.54);
       printf ("in and ");
-      wfloat (&output, node->Upr.Uellipse.elheight / 2 / fsc / 2.54);
+      wfloat (&output, node->ellipseheight_ / 2 / fsc / 2.54);
       printf ("in)");
       pgfendpath ();
-    }
+      }
     pgfwrtext (node, node->textp, node->aat.xpos, node->aat.ypos);
     break;
 
   case XLcircle:
-    if (drawn (node, lsp, node->Upr.Ucircle.cfill)) {
+    if (drawn (node, lsp, node->circlefill_)) {
       pgfstartdraw (0, node, lsp);
       wpos (node->aat);
       printf (" circle (");
-      wfloat (&output, node->Upr.Ucircle.radius / fsc / 2.54);
+      wfloat (&output, node->circleradius_ / fsc / 2.54);
       printf ("in)");
       pgfendpath ();
-    }
+      }
     pgfwrtext (node, node->textp, node->aat.xpos, node->aat.ypos);
     break;
 
   case XLarc:
     if (drawn (node, lsp, -1.0)) {
       getlinshade (node, &tn, &sshade, &soutline, &vfill, &bfill);
-      if (bfill && (vfill >= 0.0)) {
-	node->Upr.Uline.lfill = vfill;
-      }
+      if (bfill && (vfill >= 0.0)) { node->linefill_ = vfill; }
       X0 = arcstart (node);
       X1 = arcend (node);
       if (bfill) {
-	s = node->lthick;
-	node->lthick = 0.0;
-	pgfstartdraw (0, node, XLinvis);
-	node->lthick = s;
-	wpos (X0);
-	popgwarc (node->aat, fabs (node->Upr.Uline.aradius),
-		  posangle (X0, node->aat), posangle (X1, node->aat),
-		  node->Upr.Uline.endpos.ypos);
-	printf ("--cycle\n");
-	pgfendpath ();
-      }
+	    s = node->lthick;
+	    node->lthick = 0.0;
+	    pgfstartdraw (0, node, XLinvis);
+	    node->lthick = s;
+	    wpos (X0);
+	    popgwarc (node->aat, fabs (node->aradius_),
+		  posangle(X0, node->aat), posangle(X1, node->aat), node->arcangle_);
+	    printf ("--cycle\n");
+	    pgfendpath ();
+        }
       if (lsp != XLinvis) {
-	TEMP = ahlex (node->Upr.Uline.atype);
-	if ((TEMP == XDOUBLEHEAD) || (TEMP == XLEFTHEAD)) {
-	  sf = node->shadedp;
-	  node->shadedp = NULL;
-	  sg = sshade;
-	  sshade = soutline;
-	  pgfarcahead (node->aat, X0, ahnum (node->Upr.Uline.atype),
+	    TEMP = ahlex (node->lineatype_);
+	    if ((TEMP == XDOUBLEHEAD) || (TEMP == XLEFTHEAD)) {
+	      sf = node->shadedp;
+	      node->shadedp = NULL;
+	      sg = sshade;
+	      sshade = soutline;
+	      pgfarcahead(node->aat, X0, ahnum (node->lineatype_),
 		       soutline,
-		       qenv (node, XLarrowht, node->Upr.Uline.height),
-		       qenv (node, XLarrowwid, node->Upr.Uline.width), lth,
-		       fabs (node->Upr.Uline.aradius),
-		       node->Upr.Uline.endpos.ypos, &X0);
-	  node->shadedp = sf;
-	  sshade = sg;
-	}
-	TEMP = ahlex (node->Upr.Uline.atype);
-	if ((TEMP == XDOUBLEHEAD) || (TEMP == XRIGHTHEAD)) {
-	  sf = node->shadedp;
-	  node->shadedp = NULL;
-	  sg = sshade;
-	  sshade = soutline;
-	  pgfarcahead (node->aat, X1, ahnum (node->Upr.Uline.atype),
+		       qenv(node, XLarrowht, node->lineheight_),
+		       qenv(node, XLarrowwid, node->linewidth_), lth,
+		       fabs(node->aradius_), node->arcangle_, &X0);
+	      node->shadedp = sf;
+	      sshade = sg;
+	      }
+	    TEMP = ahlex (node->lineatype_);
+	    if ((TEMP == XDOUBLEHEAD) || (TEMP == XRIGHTHEAD)) {
+	      sf = node->shadedp;
+	      node->shadedp = NULL;
+	      sg = sshade;
+	      sshade = soutline;
+	      pgfarcahead(node->aat, X1, ahnum (node->lineatype_),
 		       soutline,
-		       qenv (node, XLarrowht, node->Upr.Uline.height),
-		       qenv (node, XLarrowwid, node->Upr.Uline.width), lth,
-		       -fabs (node->Upr.Uline.aradius),
-		       node->Upr.Uline.endpos.ypos, &X1);
-	  node->shadedp = sf;
-	  sshade = sg;
-	}
-	sf = node->shadedp;
-	node->shadedp = NULL;
-	sg = sshade;
-	sshade = NULL;
-	c = node->Upr.Uline.lfill;
-	node->Upr.Uline.lfill = -1.0;
-	pgfstartdraw (0, node, lsp);
-	wpos (X0);
-	popgwarc (node->aat, fabs (node->Upr.Uline.aradius),
-		  posangle (X0, node->aat), posangle (X1, node->aat),
-		  node->Upr.Uline.endpos.ypos);
-	node->shadedp = sf;
-	sshade = sg;
-	node->Upr.Uline.lfill = c;
-	pgfendpath ();
+		       qenv(node, XLarrowht, node->lineheight_),
+		       qenv(node, XLarrowwid, node->linewidth_), lth,
+		       -fabs(node->aradius_), node->arcangle_, &X1);
+	      node->shadedp = sf;
+	      sshade = sg;
+	      }
+	    sf = node->shadedp;
+	    node->shadedp = NULL;
+	    sg = sshade;
+	    sshade = NULL;
+	    c = node->linefill_;
+	    node->linefill_ = -1.0;
+	    pgfstartdraw (0, node, lsp);
+	    wpos (X0);
+	    popgwarc(node->aat, fabs (node->aradius_),
+		  posangle(X0, node->aat), posangle(X1, node->aat), node->arcangle_);
+	    node->shadedp = sf;
+	    sshade = sg;
+	    node->linefill_ = c;
+	    pgfendpath ();
+        }
       }
-    }
     pgfwrtext (node, node->textp, node->aat.xpos, node->aat.ypos);
     break;
 
@@ -458,82 +424,79 @@ pgfdraw (primitive * node) {
       getlinshade (node, &tn, &sshade, &soutline, &vfill, &bfill);
       lth = qenv (node, XLlinethick, tn->lthick);
       if (bfill) {
-	s = node->lthick;
-	node->lthick = 0.0;
-	pgfstartdraw (0, node, XLinvis);
-	node->lthick = s;
-	wpos (node->aat);
-	tx = node;
-	while (tx != NULL) {
-	  ddash ();
-	  wpos (tx->Upr.Uline.endpos);
-	  tx = tx->son;
-	}
-	printf ("--cycle\n");
-	pgfendpath ();
-      }
+	    s = node->lthick;
+	    node->lthick = 0.0;
+	    pgfstartdraw (0, node, XLinvis);
+	    node->lthick = s;
+	    wpos (node->aat);
+	    tx = node;
+	    while (tx != NULL) {
+	      ddash ();
+	      wpos (tx->endpos_);
+	      tx = tx->son;
+	      }
+	    printf ("--cycle\n");
+	    pgfendpath ();
+        }
       if (lsp != XLinvis) {
-	TEMP = ahlex (tn->Upr.Uline.atype);
-	if ((TEMP == XDOUBLEHEAD) || (TEMP == XLEFTHEAD)) {
-	  sf = node->shadedp;
-	  node->shadedp = NULL;
-	  sg = sshade;
-	  sshade = soutline;
-	  pgfstartdraw (ahnum (node->Upr.Uline.atype), node, lsp);
-	  pgfahead (ahnum (tn->Upr.Uline.atype), &node->aat,
-		    node->Upr.Uline.endpos,
-		    qenv (node, XLarrowht, tn->Upr.Uline.height),
-		    qenv (node, XLarrowwid, tn->Upr.Uline.width), lth);
-	  node->shadedp = sf;
-	  sshade = sg;
-	}
-	TEMP = ahlex (tn->Upr.Uline.atype);
-	if ((TEMP == XDOUBLEHEAD) || (TEMP == XRIGHTHEAD)) {
-	  sf = node->shadedp;
-	  node->shadedp = NULL;
-	  sg = sshade;
-	  sshade = soutline;
-	  pgfstartdraw (ahnum (node->Upr.Uline.atype), node, lsp);
-	  pgfahead (ahnum (tn->Upr.Uline.atype), &tn->Upr.Uline.endpos,
-		    tn->aat, qenv (node, XLarrowht, tn->Upr.Uline.height),
-		    qenv (node, XLarrowwid, tn->Upr.Uline.width), lth);
-	  node->shadedp = sf;
-	  sshade = sg;
-	}
-	sf = node->shadedp;
-	node->shadedp = NULL;
-	sg = sshade;
-	sshade = NULL;
-	s = node->Upr.Uline.lfill;
-	node->Upr.Uline.lfill = -1.0;
-	c = vfill;
-	vfill = -1.0;
-	pgfstartdraw (0, node, lsp);
-	node->shadedp = sf;
-	sshade = sg;
-	node->Upr.Uline.lfill = s;
-	vfill = c;
-	wpos (node->aat);
+	    TEMP = ahlex (tn->lineatype_);
+	    if ((TEMP == XDOUBLEHEAD) || (TEMP == XLEFTHEAD)) {
+	      sf = node->shadedp;
+	      node->shadedp = NULL;
+	      sg = sshade;
+	      sshade = soutline;
+	      pgfstartdraw (ahnum (node->lineatype_), node, lsp);
+	      pgfahead (ahnum (tn->lineatype_), &node->aat,
+		    node->endpos_,
+		    qenv (node, XLarrowht, tn->lineheight_),
+		    qenv (node, XLarrowwid, tn->linewidth_), lth);
+	      node->shadedp = sf;
+	      sshade = sg;
+	      }
+	    TEMP = ahlex (tn->lineatype_);
+	    if ((TEMP == XDOUBLEHEAD) || (TEMP == XRIGHTHEAD)) {
+	      sf = node->shadedp;
+	      node->shadedp = NULL;
+	      sg = sshade;
+	      sshade = soutline;
+	      pgfstartdraw (ahnum (node->lineatype_), node, lsp);
+	      pgfahead (ahnum (tn->lineatype_), &tn->endpos_,
+		    tn->aat, qenv (node, XLarrowht, tn->lineheight_),
+		    qenv (node, XLarrowwid, tn->linewidth_), lth);
+	      node->shadedp = sf;
+	      sshade = sg;
+	      }
+	    sf = node->shadedp;
+	    node->shadedp = NULL;
+	    sg = sshade;
+	    sshade = NULL;
+	    s = node->linefill_;
+	    node->linefill_ = -1.0;
+	    c = vfill;
+	    vfill = -1.0;
+	    pgfstartdraw (0, node, lsp);
+	    node->shadedp = sf;
+	    sshade = sg;
+	    node->linefill_ = s;
+	    vfill = c;
+	    wpos (node->aat);
+        }
       }
-    }
     if (lsp != XLinvis) {
       ddash ();
-      wpos (node->Upr.Uline.endpos);
-      if (node->son == NULL) {
-	pgfendpath ();
+      wpos (node->endpos_);
+      if (node->son == NULL) { pgfendpath (); }
       }
-    }
     if (node->son == NULL) {
       while (snode != NULL) {
-	With1 = snode;
-	if (With1->textp != NULL) {
-	  pgfwrtext (snode, With1->textp,
-		     0.5 * (With1->Upr.Uline.endpos.xpos + With1->aat.xpos),
-		     0.5 * (With1->aat.ypos + With1->Upr.Uline.endpos.ypos));
-	}
-	snode = snode->son;
+	    if (snode->textp != NULL) {
+	      pgfwrtext (snode, snode->textp,
+		     0.5 * (snode->endpos_.xpos + snode->aat.xpos),
+		     0.5 * (snode->aat.ypos + snode->endpos_.ypos));
+	      }
+	    snode = snode->son;
+        }
       }
-    }
     break;
 
   case XLspline:
@@ -542,69 +505,67 @@ pgfdraw (primitive * node) {
       node->lparam = tn->lparam;
       node->lthick = tn->lthick;
       if (bfill) {
-	c = node->lthick;
-	node->lthick = 0.0;
-	sg = soutline;
-	soutline = sshade;
-	pgfstartdraw (0, node, XLinvis);
-	node->lthick = c;
-	soutline = sg;
-	spltot = primdepth (node);
-	splcount = spltot;
-	tx = node;
-	while (tx != NULL) {
-	  splinesegment (tx, splcount, spltot);
-	  splcount--;
-	  tx = tx->son;
-	}
-	printf (" --cycle");
-	pgfendpath ();
-      }
+	    c = node->lthick;
+	    node->lthick = 0.0;
+	    sg = soutline;
+	    soutline = sshade;
+	    pgfstartdraw (0, node, XLinvis);
+	    node->lthick = c;
+	    soutline = sg;
+	    spltot = primdepth (node);
+	    splcount = spltot;
+	    tx = node;
+	    while (tx != NULL) {
+	      splinesegment (tx, splcount, spltot);
+	      splcount--;
+	      tx = tx->son;
+	      }
+	    printf (" --cycle");
+	    pgfendpath ();
+        }
       if (lsp != XLinvis) {
-	spltot = primdepth (node);
-	splcount = spltot;
-	TEMP = ahlex (tn->Upr.Uline.atype);
-	if ((TEMP == XDOUBLEHEAD) || (TEMP == XLEFTHEAD)) {
-	  sf = node->shadedp;
-	  node->shadedp = NULL;
-	  sg = sshade;
-	  sshade = soutline;
-	  pgfstartdraw (ahnum (tn->Upr.Uline.atype), node, lsp);
-	  pgfahead (ahnum (tn->Upr.Uline.atype), &node->aat,
-		    node->Upr.Uline.endpos,
-		    qenv (node, XLarrowht, tn->Upr.Uline.height),
-		    qenv (node, XLarrowwid, tn->Upr.Uline.width),
+	    spltot = primdepth (node);
+	    splcount = spltot;
+	    TEMP = ahlex (tn->lineatype_);
+	    if ((TEMP == XDOUBLEHEAD) || (TEMP == XLEFTHEAD)) {
+	      sf = node->shadedp;
+	      node->shadedp = NULL;
+	      sg = sshade;
+	      sshade = soutline;
+	      pgfstartdraw (ahnum (tn->lineatype_), node, lsp);
+	      pgfahead (ahnum (tn->lineatype_), &node->aat,
+		    node->endpos_,
+		    qenv (node, XLarrowht, tn->lineheight_),
+		    qenv (node, XLarrowwid, tn->linewidth_),
 		    qenv (node, XLlinethick, tn->lthick));
-	  node->shadedp = sf;
-	  sshade = sg;
-	}
-	TEMP = ahlex (tn->Upr.Uline.atype);
-	if ((TEMP == XDOUBLEHEAD) || (TEMP == XRIGHTHEAD)) {
-	  sf = tn->shadedp;
-	  tn->shadedp = NULL;
-	  sg = sshade;
-	  sshade = soutline;
-	  pgfstartdraw (ahnum (tn->Upr.Uline.atype), tn, lsp);
-	  pgfahead (ahnum (tn->Upr.Uline.atype), &tn->Upr.Uline.endpos,
-		    tn->aat, qenv (node, XLarrowht, tn->Upr.Uline.height),
-		    qenv (node, XLarrowwid, tn->Upr.Uline.width),
+	      node->shadedp = sf;
+	      sshade = sg;
+	      }
+	    TEMP = ahlex (tn->lineatype_);
+	    if ((TEMP == XDOUBLEHEAD) || (TEMP == XRIGHTHEAD)) {
+	      sf = tn->shadedp;
+	      tn->shadedp = NULL;
+	      sg = sshade;
+	      sshade = soutline;
+	      pgfstartdraw (ahnum (tn->lineatype_), tn, lsp);
+	      pgfahead (ahnum (tn->lineatype_), &tn->endpos_,
+		    tn->aat, qenv (node, XLarrowht, tn->lineheight_),
+		    qenv (node, XLarrowwid, tn->linewidth_),
 		    qenv (node, XLlinethick, tn->lthick));
-	  tn->shadedp = sf;
-	  sshade = sg;
-	}
-	deletename (&node->shadedp);
-	sshade = NULL;
-	node->Upr.Uline.lfill = -1.0;
-	vfill = -1.0;
-	pgfstartdraw (0, node, lsp);
+	      tn->shadedp = sf;
+	      sshade = sg;
+	      }
+	    deletename (&node->shadedp);
+	    sshade = NULL;
+	    node->linefill_ = -1.0;
+	    vfill = -1.0;
+	    pgfstartdraw (0, node, lsp);
+        }
       }
-    }
     if (lsp != XLinvis) {
       splinesegment (node, splcount, spltot);
-      if (splcount == 1) {
-	pgfendpath ();
+      if (splcount == 1) { pgfendpath (); }
       }
-    }
     splcount--;
     break;
 
@@ -615,10 +576,8 @@ pgfdraw (primitive * node) {
   case XLaTeX:
     if (node->textp != NULL) {
       wstring (&output, node->textp);
-      putchar ('\n');
-    } else if (node->lthick >= 0.0) {
-      pgfsetthick (node->lthick);
-    }
+      putchar ('\n'); }
+    else if (node->lthick >= 0.0) { pgfsetthick (node->lthick); }
     break;
   }
 }				/* pgfdraw */
